* mln/topo/internal/complex_iter_base.hh
(mln::topo::internal::complex_iter_base_<F, E>): Rename as...
(mln::topo::internal::complex_iter_base<F, E>): ...this.
* milena/mln/topo/attic/complex_faces_iter.hh,
* milena/mln/topo/attic/faces_iter.hh,
* milena/mln/topo/complex_iter.hh:
Adjust clients.
---
milena/ChangeLog | 12 +++++++++++
milena/mln/topo/attic/complex_faces_iter.hh | 16 +++++++-------
milena/mln/topo/attic/faces_iter.hh | 16 +++++++-------
milena/mln/topo/complex_iter.hh | 16 ++++++--------
milena/mln/topo/internal/complex_iter_base.hh | 26 ++++++++++++------------
5 files changed, 48 insertions(+), 38 deletions(-)
diff --git a/milena/ChangeLog b/milena/ChangeLog
index d105628..e129023 100644
--- a/milena/ChangeLog
+++ b/milena/ChangeLog
@@ -1,5 +1,17 @@
2008-09-26 Roland Levillain <roland(a)lrde.epita.fr>
+ Rename internal::complex_iter_base_ as internal::complex_iter_base.
+
+ * mln/topo/internal/complex_iter_base.hh
+ (mln::topo::internal::complex_iter_base_<F, E>): Rename as...
+ (mln::topo::internal::complex_iter_base<F, E>): ...this.
+ * milena/mln/topo/attic/complex_faces_iter.hh,
+ * milena/mln/topo/attic/faces_iter.hh,
+ * milena/mln/topo/complex_iter.hh:
+ Adjust clients.
+
+2008-09-26 Roland Levillain <roland(a)lrde.epita.fr>
+
Disable old iterators on n-faces (with n statically known).
* milena/mln/core/site_set/p_complex_faces_piter.hh,
diff --git a/milena/mln/topo/internal/complex_iter_base.hh
b/milena/mln/topo/internal/complex_iter_base.hh
index d371372..8e20801 100644
--- a/milena/mln/topo/internal/complex_iter_base.hh
+++ b/milena/mln/topo/internal/complex_iter_base.hh
@@ -53,9 +53,9 @@ namespace mln
/// \arg \p F The type of the face handle.
/// \arg \p E The type exact type of the iterator.
template <typename F, typename E>
- class complex_iter_base_ : public Iterator<E>
+ class complex_iter_base : public Iterator<E>
{
- typedef complex_iter_base_<F, E> self_;
+ typedef complex_iter_base<F, E> self_;
public:
typedef F face;
@@ -67,8 +67,8 @@ namespace mln
/// \{
/* FIXME: Keep this non-const? See a (big) comment about this in
milena/tests/complex_image.cc. */
- complex_iter_base_();
- complex_iter_base_(complex_type& c);
+ complex_iter_base();
+ complex_iter_base(complex_type& c);
/// \}
/// Manipulation.
@@ -104,7 +104,7 @@ namespace mln
template <typename F, typename E>
inline
std::ostream&
- operator<<(std::ostream& ostr, const complex_iter_base_<F, E>&
p);
+ operator<<(std::ostream& ostr, const complex_iter_base<F, E>&
p);
@@ -112,7 +112,7 @@ namespace mln
template <typename F, typename E>
inline
- complex_iter_base_<F, E>::complex_iter_base_()
+ complex_iter_base<F, E>::complex_iter_base()
{
// Ensure F and E are compatible.
mlc_equal(F, typename E::face)::check();
@@ -122,7 +122,7 @@ namespace mln
template <typename F, typename E>
inline
- complex_iter_base_<F, E>::complex_iter_base_(complex_type& c)
+ complex_iter_base<F, E>::complex_iter_base(complex_type& c)
{
// Ensure F and E are compatible.
mlc_equal(F, typename E::face)::check();
@@ -135,7 +135,7 @@ namespace mln
template <typename F, typename E>
inline
void
- complex_iter_base_<F, E>::set_cplx(complex_type& c)
+ complex_iter_base<F, E>::set_cplx(complex_type& c)
{
face_.set_cplx(c);
// Invalidate face_.
@@ -145,7 +145,7 @@ namespace mln
template <typename F, typename E>
inline
bool
- complex_iter_base_<F, E>::is_valid() const
+ complex_iter_base<F, E>::is_valid() const
{
return face_.is_valid();
}
@@ -153,7 +153,7 @@ namespace mln
template <typename F, typename E>
inline
void
- complex_iter_base_<F, E>::invalidate()
+ complex_iter_base<F, E>::invalidate()
{
face_.invalidate();
}
@@ -161,14 +161,14 @@ namespace mln
template <typename F, typename E>
inline
const F&
- complex_iter_base_<F, E>::to_face() const
+ complex_iter_base<F, E>::to_face() const
{
return face_;
}
template <typename F, typename E>
inline
- complex_iter_base_<F, E>::operator F() const
+ complex_iter_base<F, E>::operator F() const
{
mln_precondition(is_valid());
return face_;
@@ -178,7 +178,7 @@ namespace mln
template <typename F, typename E>
inline
std::ostream&
- operator<<(std::ostream& ostr, const complex_iter_base_<F, E>&
p)
+ operator<<(std::ostream& ostr, const complex_iter_base<F, E>&
p)
{
/* FIXME: We should use p.to_face() here, but as it lacks the
precondition the conversion operator has, so we use the latter.
diff --git a/milena/mln/topo/attic/complex_faces_iter.hh
b/milena/mln/topo/attic/complex_faces_iter.hh
index 95d7901..c0d278c 100644
--- a/milena/mln/topo/attic/complex_faces_iter.hh
+++ b/milena/mln/topo/attic/complex_faces_iter.hh
@@ -56,8 +56,8 @@ namespace mln
/// \arg \p D The dimension of the complex this iterator belongs to.
template <unsigned N, unsigned D>
class complex_faces_fwd_iter_
- : public internal::complex_iter_base_< face<D>,
- complex_faces_fwd_iter_<N, D> >
+ : public internal::complex_iter_base< face<D>,
+ complex_faces_fwd_iter_<N, D> >
{
public:
/// Type of associated face.
@@ -65,7 +65,7 @@ namespace mln
private:
typedef complex_faces_fwd_iter_<N, D> self_;
- typedef internal::complex_iter_base_< face, self_ > super_;
+ typedef internal::complex_iter_base< face, self_ > super_;
public:
using super_::is_valid;
@@ -75,7 +75,7 @@ namespace mln
/// Construction and assignment.
/// \{
complex_faces_fwd_iter_();
// FIXME: See comment in internal::complex_iter_base_'s default ctor
complex_faces_fwd_iter_(complex<D>& c);
/// \}
@@ -102,8 +102,8 @@ namespace mln
/// \arg \p D The dimension of the complex this iterator belongs to.
template <unsigned N, unsigned D>
class complex_faces_bkd_iter_
- : public internal::complex_iter_base_< face<D>,
- complex_faces_bkd_iter_<N, D> >
+ : public internal::complex_iter_base< face<D>,
+ complex_faces_bkd_iter_<N, D> >
{
public:
/// Type of associated face.
@@ -111,7 +111,7 @@ namespace mln
private:
typedef complex_faces_bkd_iter_<N, D> self_;
- typedef internal::complex_iter_base_< face, self_ > super_;
+ typedef internal::complex_iter_base< face, self_ > super_;
public:
using super_::is_valid;
@@ -121,7 +121,7 @@ namespace mln
/// Construction and assignment.
/// \{
complex_faces_bkd_iter_();
// FIXME: See comment in internal::complex_iter_base_'s default ctor
complex_faces_bkd_iter_(complex<D>& c);
/// \}
@@ -75,7 +75,7 @@ namespace mln
/// \{
complex_faces_fwd_iter_();
- // FIXME: See comment in internal::complex_iter_base_'s default ctor
+ // FIXME: See comment in internal::complex_iter_base's default ctor
complex_faces_fwd_iter_(complex<D>& c);
/// \}
@@ -121,7 +121,7 @@ namespace mln
/// \{
complex_faces_bkd_iter_();
- // FIXME: See comment in internal::complex_iter_base_'s default ctor
+ // FIXME: See comment in internal::complex_iter_base's default ctor
complex_faces_bkd_iter_(complex<D>& c);
/// \}
diff --git a/milena/mln/topo/attic/faces_iter.hh b/milena/mln/topo/attic/faces_iter.hh
index 509ed9c..9497a14 100644
--- a/milena/mln/topo/attic/faces_iter.hh
+++ b/milena/mln/topo/attic/faces_iter.hh
@@ -51,8 +51,8 @@ namespace mln
/// \arg \p D The dimension of the complex this iterator belongs to.
template <unsigned N, unsigned D>
class faces_fwd_iter_
- : public internal::complex_iter_base_< n_face<N, D>,
- faces_fwd_iter_<N, D> >
+ : public internal::complex_iter_base< n_face<N, D>,
+ faces_fwd_iter_<N, D> >
{
public:
/// Type of associated face.
@@ -60,7 +60,7 @@ namespace mln
private:
typedef faces_fwd_iter_<N, D> self_;
- typedef internal::complex_iter_base_< face, self_ > super_;
+ typedef internal::complex_iter_base< face, self_ > super_;
public:
using super_::is_valid;
@@ -70,7 +70,7 @@ namespace mln
/// Construction and assignment.
/// \{
faces_fwd_iter_();
// FIXME: See comment in internal::complex_iter_base_'s default ctor
faces_fwd_iter_(complex<D>& c);
/// \}
@@ -97,8 +97,8 @@ namespace mln
/// \arg \p D The dimension of the complex this iterator belongs to.
template <unsigned N, unsigned D>
class faces_bkd_iter_
- : public internal::complex_iter_base_< n_face<N, D>,
- faces_bkd_iter_<N, D> >
+ : public internal::complex_iter_base< n_face<N, D>,
+ faces_bkd_iter_<N, D> >
{
public:
/// Type of associated face.
@@ -106,7 +106,7 @@ namespace mln
private:
typedef faces_bkd_iter_<N, D> self_;
- typedef internal::complex_iter_base_< face, self_ > super_;
+ typedef internal::complex_iter_base< face, self_ > super_;
public:
using super_::is_valid;
@@ -116,7 +116,7 @@ namespace mln
/// Construction and assignment.
/// \{
faces_bkd_iter_();
// FIXME: See comment in internal::complex_iter_base_'s default ctor
faces_bkd_iter_(complex<D>& c);
/// \}
@@ -70,7 +70,7 @@ namespace mln
/// \{
faces_fwd_iter_();
- // FIXME: See comment in internal::complex_iter_base_'s default ctor
+ // FIXME: See comment in internal::complex_iter_base's default ctor
faces_fwd_iter_(complex<D>& c);
/// \}
@@ -116,7 +116,7 @@ namespace mln
/// \{
faces_bkd_iter_();
- // FIXME: See comment in internal::complex_iter_base_'s default ctor
+ // FIXME: See comment in internal::complex_iter_base's default ctor
faces_bkd_iter_(complex<D>& c);
/// \}
diff --git a/milena/mln/topo/complex_iter.hh b/milena/mln/topo/complex_iter.hh
index 32bbb1f..c589093 100644
--- a/milena/mln/topo/complex_iter.hh
+++ b/milena/mln/topo/complex_iter.hh
@@ -34,7 +34,7 @@
# include <mln/topo/internal/complex_iter_base.hh>
# include <mln/topo/face.hh>
// FIXME: Factor a bit more? (Using complex_iter_base_.)
namespace mln
@@ -56,8 +56,7 @@ namespace mln
/// \arg \p D The dimension of the complex this iterator belongs to.
template <unsigned D>
class complex_fwd_iter_
- : public internal::complex_iter_base_< face<D>,
- complex_fwd_iter_<D> >
+ : public internal::complex_iter_base< face<D>, complex_fwd_iter_<D>
>
{
public:
/// Type of associated face.
@@ -65,7 +64,7 @@ namespace mln
private:
typedef complex_fwd_iter_<D> self_;
- typedef internal::complex_iter_base_< face, self_ > super_;
+ typedef internal::complex_iter_base< face, self_ > super_;
public:
using super_::is_valid;
@@ -75,7 +74,7 @@ namespace mln
/// Construction and assignment.
/// \{
complex_fwd_iter_();
// FIXME: See comment in internal::complex_iter_base_'s default ctor
complex_fwd_iter_(complex<D>& c);
/// \}
@@ -101,8 +100,7 @@ namespace mln
/// \arg \p D The dimension of the complex this iterator belongs to.
template <unsigned D>
class complex_bkd_iter_
- : public internal::complex_iter_base_< face<D>,
- complex_bkd_iter_<D> >
+ : public internal::complex_iter_base< face<D>, complex_bkd_iter_<D>
>
{
public:
/// Type of associated face.
@@ -110,7 +108,7 @@ namespace mln
private:
typedef complex_bkd_iter_<D> self_;
- typedef internal::complex_iter_base_< face, self_ > super_;
+ typedef internal::complex_iter_base< face, self_ > super_;
public:
using super_::is_valid;
@@ -120,7 +118,7 @@ namespace mln
/// Construction and assignment.
/// \{
complex_bkd_iter_();
// FIXME: See comment in internal::complex_iter_base_'s default ctor
complex_bkd_iter_(complex<D>& c);
/// \}
@@ -34,7 +34,7 @@
# include <mln/topo/internal/complex_iter_base.hh>
# include <mln/topo/face.hh>
-// FIXME: Factor a bit more? (Using complex_iter_base_.)
+// FIXME: Factor a bit more? (Using complex_iter_base.)
namespace mln
@@ -75,7 +74,7 @@ namespace mln
/// \{
complex_fwd_iter_();
- // FIXME: See comment in internal::complex_iter_base_'s default ctor
+ // FIXME: See comment in internal::complex_iter_base's default ctor
complex_fwd_iter_(complex<D>& c);
/// \}
@@ -120,7 +118,7 @@ namespace mln
/// \{
complex_bkd_iter_();
- // FIXME: See comment in internal::complex_iter_base_'s default ctor
+ // FIXME: See comment in internal::complex_iter_base's default ctor
complex_bkd_iter_(complex<D>& c);
/// \}
--
1.6.0.1